@@ -98,7 +98,11 @@ class Resize(object):
 			img = IMG.resize(img, self.size)
 			points = PNT.scale(points, (scaleX, scaleY))
 		else:
-			img = IMG.resize_keep_ratio(img, self.size, fillcolor=self.fillcolor)
+			if self.fillcolor is 'random':
+				fillcolor = tuple(np.random.choice(range(256), size=3))
+			else:
+				fillcolor=self.fillcolor
+			img = IMG.resize_keep_ratio(img, self.size, fillcolor=fillcolor)
 			rx = w / tw
 			ry = h / th
 			r = max(rx, ry)
@@ -150,6 +154,10 @@ class RandomTranslate(object):
 		self.fillcolor = fillcolor
 
 	def __call__(self, img, points):
+		if self.fillcolor is 'random':
+			fillcolor = tuple(np.random.choice(range(256), size=3))
+		else:
+			fillcolor = self.fillcolor
 		rang = PNT.get_translate_range(points, img.size)
 		if self.max_offset:
 			def limit_box(box, limits=None):
@@ -175,20 +183,25 @@ class RandomTranslate(object):
 				return img, points
 		ofx = random.randint(rang[0], rang[2])
 		ofy = random.randint(rang[1], rang[3])
-		img = IMG.translate(img, offset=(ofx, ofy), fillcolor=self.fillcolor)
+		img = IMG.translate(img, offset=(ofx, ofy), fillcolor=fillcolor)
 		points = [PNT.translate(pnts, (ofx, ofy)) for pnts in points]
 		return img, points
 
 
 class RandomRotate(object):
-	def __init__(self, degree, expand=True):
+	def __init__(self, degree, expand=True,fillcolor='black'):
 		self.degree = degree if not isinstance(degree, numbers.Number) else [-degree, degree]
 		self.expand = expand
+		self.fillcolor=fillcolor
 
 	def __call__(self, img, points):
+		if self.fillcolor is 'random':
+			fillcolor = tuple(np.random.choice(range(256), size=3))
+		else:
+			fillcolor = self.fillcolor
 		degree = random.random() * (self.degree[1] - self.degree[0]) + self.degree[0]
 		w, h = img.size
-		img = IMG.rotate(img, degree, expand=self.expand)
+		img = IMG.rotate(img, degree, expand=self.expand,fillcolor=fillcolor)
 		points = [PNT.rotate(pnts, degree, (w // 2, h // 2), img_size=(w, h), expand=self.expand) for pnts in points]
 		return img, points
 
@@ -218,24 +231,34 @@ class RandomShearY(object):
 
 
 class RandomShear(object):
-	def __init__(self, xdegree, ydegree=None):
+	def __init__(self, xdegree, ydegree=None,fillcolor='balck'):
 		def get_param(param, defualt=None):
 			if param is None: return defualt
 			return param if not isinstance(param, numbers.Number) else [-param, param]
 
 		self.xdegree = get_param(xdegree)
 		self.ydegree = get_param(ydegree)
+		self.fillcolor=fillcolor
 
 	def __call__(self, img, points):
+
 		if self.xdegree:
+			if self.fillcolor is 'random':
+				fillcolor = tuple(np.random.choice(range(256), size=3))
+			else:
+				fillcolor = self.fillcolor
 			degree = random.random() * (self.xdegree[1] - self.xdegree[0]) + self.xdegree[0]
 			w, h = img.size
-			img = IMG.shear_x(img, degree)
+			img = IMG.shear_x(img, degree,fillcolor=fillcolor)
 			points = [PNT.shear_x(pnts, degree, img_size=(w, h), expand=True) for pnts in points]
 		if self.ydegree:
+			if self.fillcolor is 'random':
+				fillcolor = tuple(np.random.choice(range(256), size=3))
+			else:
+				fillcolor = self.fillcolor
 			degree = random.random() * (self.ydegree[1] - self.ydegree[0]) + self.ydegree[0]
 			w, h = img.size
-			img = IMG.shear_y(img, degree)
+			img = IMG.shear_y(img, degree,fillcolor=fillcolor)
 			points = [PNT.shear_y(pnts, degree, img_size=(w, h), expand=True) for pnts in points]
 		return img, points
 
@@ -360,26 +383,48 @@ class RandomAffine(object):
 
 
 def demo():
+
 	transform = Compose([
 		# BboxToPoints(),
-		Resize((512, 512)),
+		Limitsize(600),
 		Zip([
 			Compose([
-				BT.ColorJitter(brightness=0.5, contrast=0.5, saturation=0.5, hue=0.5)
+				# BT.RandomApply(IMG.equalize,p=1),
+			]),
+			Identical(),
+		]),
+		RandomRotate(30,fillcolor='random'),
+		RandomShear(30, 30,fillcolor='random'),
+		RandomTranslate(max_offset=[100, 100],fillcolor='random'),
+		RandomHorizontalFlip(),
+		RandomVerticalFlip(),
+		Zip([
+			Compose([
+				BT.ColorJitter(brightness=0.5, contrast=0.5, saturation=0.5, hue=0.5),
+				BT.RandomOrder([
+					BT.RandomApply(IMG.sp_noise,p=1),
+					# BT.RandomApply(IMG.gaussian_noise,p=0.2),
+					# BT.RandomApply(IMG.blur,p=0.2),
+					# BT.RandomApply(IMG.box_blur,p=1,radius=2),
+					# BT.RandomApply(IMG.model_filter,p=1),
+					# BT.RandomChoice([
+						# BT.RandomApply(IMG.edge, p=1),
+						# BT.RandomApply(IMG.edge_enhance,p=1),
+						# BT.RandomApply(IMG.edge_enhance_more,p=1),
+					# ]),
+					# BT.RandomApply(IMG.contour,p=1),
+					# BT.RandomApply(IMG.emboss,p=1),
+					# BT.RandomApply(IMG.equalize,p=1)
+				])
 			]),
 			Identical()
 		]),
-		RandomRotate(30),
-		RandomShear(30, 30),
-		RandomTranslate(max_offset=[100, 100]),
-		RandomHorizontalFlip(),
-		RandomVerticalFlip(),
-		Resize((512, 512), keep_ratio=True, fillcolor='green'),
+		Resize((512, 512), keep_ratio=True, fillcolor='random'),
 		# Limitsize((128,1024)),
 	])
 	img = Image.open('/home/ars/图片/2.jpeg').convert('RGB')
 
-	points = [
+	polygon = [
 		[
 			200.6045627376426,
 			63.30798479087453
@@ -409,9 +454,9 @@ def demo():
 			73.76425855513308
 		]
 	]
-	img, points = transform(img, [points])
+	img, polygons = transform(img, [polygon])
 	# print(points)
-	img = wpcv.draw_polygon(img, points[0], width=3)
+	img = wpcv.draw_polygon(img, polygons[0], width=3)
 	img.show()
 	# print(img.size, box)
 
